@@ -12,7 +12,7 @@
 # WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF 
 # MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
-# $Id: Webdav.pm,v 1.8 2001/06/04 13:14:30 richter Exp $
+# $Id: Webdav.pm,v 1.10 2001/06/05 09:22:36 richter Exp $
 #
 ############################################################################
 
@@ -25,7 +25,7 @@ use vars qw($VERSION @ISA $initdone);
 
 require Exporter;
 
-$VERSION = "0.1.9-0.14.0";
+$VERSION = "0.1.10-0.15.0";
 
 require DynaLoader;
 
@@ -45,7 +45,7 @@ sub new
         }
 
 
-    my $sess = HTTP::Webdav::Util::http_session_create () ;
+    my $sess = HTTP::Webdav::Util::session_create () ;
 
     return $sess;
     }
